#
# spec file for package haruna
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           haruna
Version:        0.6.3
Release:        bp153.1.1
Summary:        Video player built with Qt/QML on top of libmpv
License:        CC-BY-4.0 AND GPL-3.0-or-later AND WTFPL
URL:            https://github.com/g-fb/haruna
Source0:        https://github.com/g-fb/haruna/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  breeze5-icons
BuildRequires:  cmake >= 3.15
BuildRequires:  extra-cmake-modules >= 1.0.0
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5FileMetaData)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IconThemes)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Kirigami2)
BuildRequires:  cmake(KF5XmlGui)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5QuickControls2)
BuildRequires:  pkgconfig(mpv)
# recheck this one
Requires:       breeze5-icons

%description
%{name} is a video player built with Qt/QML on top of libmpv.

%prep
%autosetup -p1

%build
%cmake
%cmake_build

%install
%cmake_install

%files
%license LICENSES/CC-BY-4.0.txt LICENSES/GPL-3.0-or-later.txt LICENSES/WTFPL.txt
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/com.georgefb.haruna.desktop
%{_datadir}/icons/hicolor/*/apps/com.georgefb.haruna.svg
%{_datadir}/metainfo/com.georgefb.haruna.appdata.xml

%changelog
* Wed Apr 28 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.6.3
  * Set breeze icon theme before QApplication creation
* Sat Apr 17 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.6.2
  * MpvObject: set youtube-dl format before loading file
  * Bundle ssl certs from certify
* Wed Apr  7 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.6.1
  * Update desktop file
  * add link to flathub page
  * MpvObject
  * Playlist model
* Wed Mar 31 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.6.0
  * Remove color schemes until their license is clear
  * MPVObject: show loading indicator for all videos
  * Disable next/previous buttons when there's 1 or no video in
    the playlist
  * Add youtube-dl to dependencies list
  * Don't use breeze icons by default
  * GUI style
  * Add copyrights
  * Correct copyright and license for cmake/FindLibmpv.cmake
  * MenuBar
  * Add checks before trying to access data
  * MpvObject
  * PlaylistModel: avoid index out of range error
  * Audio/Subtitles settings
  * Always open first video in new youtube playlist
  * Remove wrong license files
  * Add license to files without one
  * Skip videos that can't be played
  * Add loading indicator for youtube videos
  * If youtube-dl is not available display a message instead of
    the controls to open a url
  * PlayListItemWithThumbnail change elide mode to
    WrapAtWordBoundaryOrAnywhere
  * Add dependencies and build instructions to readme file
  * Youtube playlist
  * PlaylistItem
  * Worker::getMetaData return if there's no extractor available
  * CMake
  * Make mpris player dbus interface a qml context property
  * Add mpris2 support
  * Fix play next/prev actions not updating the LastPlayedFile
  * Use LabelWithTooltip without prefix
  * Add placeholder and tooltip for 'Skip chapters' feature Add
    help for 'Remember time position' and 'Skip chapters' features
  * Refactor time position saving
  * Rename custom label component to LabelWithTooltip
  * MpvObject: fix cursor not hiding in fullscreen
  * MpvObject: resume playback changes
  * Settings: don't togggle hw decoding with save file position
    checkbox
  * Update README.md
  * Add FUNDING.yml
  * Settings: change default screenshots folder
  * MpvObject: add resume/restart video popup
  * Settings: add option to disable file position saving and
    resuming
  * MpvObject: update tracks models when mpv's track-list changes
  * Remove console.log
  * MpvObject: allow loading subtitles through drag and drop
  * MpvObject: allow to print the error in get/setProperty
    methods
  * MpvObject: move loadFile function to the cpp side
  * Application: make getFileContent parameter const
  * MpvObject
  * MpvObject
  * main.qml: fix mpv.scrollPositionTimer ->
    playList.scrollPositionTimer
  * Generate AppImage from every build (#43)
  * Settings
  * Update help for old Breeze style option to fit the changes
  * Settings: remove notice about Breeze not being installed
  * SettingsBasePage: replace i18n with qsTr
  * MpvObject: fix next file not loading when current file
    finishes
  * Playback Settings
  * Remove wrong and unused id
  * Use add command to change volume and speed properties Set
    max volume to 100
  * CMake: make set_package_properties more compact
  * Seetings navigation: Set padding for each side, fix for Qt
    5.12
  * Register PlayListModel type for qml usage
  * CMake: add FindLibmpv.cmake file
  * Add liberapay and paypal donation links
  * Refactor file loading code
  * application.h: reorder some functions, remove some unused
    code
  * Refactor youtube playlist code
  * MpvObject: comment code in getYouTubePlaylist
  * Thumbnail image provider: provide generic icon for urls
  * MpvObject: extract youtube playlist code to function
  * Refactor to allow opening youtube playlists through "Open
    Url"
  * Show osd message when toggling deinterlacing
  * Header: use only one RowLayout
  * Playlist: remove style property, use PlaylistSettings.style
  * Header: remove buttons to toggle playlist Footer: use
    loaders for the playlist toggle button
  * data/appdata.xml: Make validation successful
  * Add import path for qml components
  * Actions: rename "Toggle Playlist" to "Playlist"
  * MpvVideo: consider the playlist position when anchoring
  * Header, Footer: add another button to toggle the playlist,
    one on the left and one on the right coresponding to the
    playlist's position
  * Playlist: add compact style
  * Playlist: fix playlist items coloring
  * Playlist: add option to push video instead of overlaying it
  * Add button in the header and footer to toggle the playlist
    when toggling it with the mouse is disabled
  * MpvVideo: settings are in a window so ancoring to it is wrong
  * Settings: refactor mouse page
  * Settings: add custom component for images adjustments sliders
  * Setings: remove color adjustments page
  * SettingsHeader: add top margin
  * Settings: make casing consistent
  * Settings: remove unneeded properties
  * Refactor settings window
  * Make configure header button uncheckable Don't close
    settings window (if open) when going fullscreen
  * Add action to toggle video deinterlacing
  * Open settings in separate window
  * qthelper.h: fix build with Qt 5.12
- Drop haruna-0.5.0-Qt512_fix.patch (merged upstream)
* Wed Jan 20 2021 aloisio@gmx.com
- Add haruna-0.5.0-Qt512_fix.patch
* Mon Jan 11 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.5.0
  * Update about data
  * Playback settings: remove unnecesary layout
  * Refactor settings pages
  * Add SettingsHeader component
  * Settings: add option to toggle hardware decoding
  * MpvObject: move code from eventHandler to connections
  * Replace mpv_set_option_string with setProperty
  * mpvopbject.cpp: use const container in tracks loop, clazy
    range-loop
  * qthelper: remove deprecated functions
  * Emit signals when tracks change
  * Refactor audio and subtitle tracks model into properties
  * Remove unused code
  * Add emit before dataChanged signal
  * Settings: fix open config file and folder not working
  * Settings: add help page for general settings
  * Settings: check if the Breeze style is available,
  * Settings: split useBreezeTheme in two settings,
  * Save SkipChapters setting when changed from progress bar menu
  * Add option to set file dialog location
  * CMake: look for breeze, kirigami and qt5qml
  * Fix breeze icon theme name
  * Add option to use the breeze icon theme and GUI style
  * Link against KIconThemes
  * Fix video not playing when opened from playlist
  * CMake: remove REQUIRED from find_package
  * Use the new label component where appropriate
  * Add custom label component
* Wed Dec  9 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.4.2
  * Mouse Settings: use ListModel instead of array
  * Fix mouse actions
- Drop haruna-0.4.1-fix_mouse_actions.patch (merged upstream)
* Tue Dec  8 2020 aloisio@gmx.com
- Add haruna-0.4.1-fix_mouse_actions.patch
* Tue Dec  8 2020 aloisio@gmx.com
- Update to version 0.4.1
  * Fix build on Qt 5.12
  * Save last played file
  version 0.4.0:
  * Change back to qmlRegisterSingletonType
  * add some mimetypes and KDE file handlers (from mpv)
  * Use KConfig to handle settings
  * Fix crash when using the playPrevious action
  * Settings: fix ComboBox delegate width
  * Change back to Flickable for the help window
  * CMake: fix file paths
  * Add license files for color scheme files
  * CMake: fix target_include_directories paths
  * CMake: add option to install color schemes
  * CMake: use target_include_directories and update includes
  * Rename Settings folder to settings
  * CMake: use target_sources
  * Playlist: highlight playing video
  * Add option to switch between simple playlist items
  * Add PlayListItemWithThumbnail component
  * Add image provider for video thumbnails
- Drop haruna-0.3.1-fix_crash_wih_Qt512.patch
  and haruna-0.3.1-fix_version.patch (merged upstream)
* Fri Dec  4 2020 aloisio@gmx.com
- Add haruna-0.3.1-fix_crash_wih_Qt512.patch and
  haruna-0.3.1-fix_version.patch
* Tue Dec  1 2020 aloisio@gmx.com
- Update to version 0.3.1
  * Playlist: always hide horizontal scrollbar
  * Add include for QPointer in application.cpp
  * Fix includes in application.cpp
- Drop haruna-0.3.0-QPointer.patch (merged upstream)
* Tue Dec  1 2020 aloisio@gmx.com
- Update to version 0.3.0
  * Playlist: hide horizontal scrollbar
  * Cleanup Application constructor
  * Move code from main.cpp to application.cpp
  * Move qml type registration, thread, about data and
  * MPV: refactor loading file code
  * MPV: make pause property writable
  * Use ScrollView and TextArea for help pages
  * Pass all metadata from worker to playlist model
  * ProgressBar: Disable middle click when chapter markers are
    hidden
  * Add option to hide chapter markers
  * Fix menu and header toggle actions breaking binding of
    'visible' prop…
  * Add help menu with about haruna action
  * Add about action
  * Use KAboutData setters for more clarity
  * Remove feature_summary from src/CMakeLists.txt
  * Upper case fusion style name
  * Use mpv.command to load file from playlist
  * Add setting to disable adding videos from same folder to
    playlist
  * Add clear method to playlist model
  * Add playlistitem constructor and set its properties inside it
  * Play next action jumps to first video if current video is
  * Add setting to repeat playlist or stop after last video
    finished
  * Add watchPercentage property to mpv,
- Add haruna-0.3.0-QPointer.patch
* Mon Nov  2 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.2.2
  * Fixed incompatibilities with Qt 5.12
- Drop haruna-desktop.patch, haruna-qt512_1.patch and
  haruna-qt512_2.patch
* Wed Oct 14 2020 Luigi Baldoni <aloisio@gmx.com>
- Initial package (v0.2.1)
